==> zio-aws-wisdom_3-5.17.103.1-sources.jar: zio/aws/wisdom/model/SearchContentResponse.scala <==
package zio.aws.wisdom.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.wisdom.model.primitives.NextToken
import scala.jdk.CollectionConverters.*
final case class SearchContentResponse(
    contentSummaries: Iterable[zio.aws.wisdom.model.ContentSummary],
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.wisdom.model.SearchContentResponse = {
    import SearchContentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.wisdom.model.SearchContentResponse
      .builder()
      .contentSummaries(contentSummaries.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.wisdom.model.SearchContentResponse.ReadOnly =
    zio.aws.wisdom.model.SearchContentResponse.wrap(buildAwsValue())
}
object SearchContentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.wisdom.model.SearchContentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wisdom.model.SearchContentResponse =
      zio.aws.wisdom.model.SearchContentResponse(
        contentSummaries.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def contentSummaries: List[zio.aws.wisdom.model.ContentSummary.ReadOnly]
    def nextToken: Option[NextToken]
    def getContentSummaries: ZIO[Any, Nothing, List[
      zio.aws.wisdom.model.ContentSummary.ReadOnly
    ]] = ZIO.succeed(contentSummaries)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.wisdom.model.SearchContentResponse
  ) extends zio.aws.wisdom.model.SearchContentResponse.ReadOnly {
    override val contentSummaries
        : List[zio.aws.wisdom.model.ContentSummary.ReadOnly] = impl
      .contentSummaries()
      .asScala
      .map { item =>
        zio.aws.wisdom.model.ContentSummary.wrap(item)
      }
      .toList
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.wisdom.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.wisdom.model.SearchContentResponse
  ): zio.aws.wisdom.model.SearchContentResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-wisdom_3-5.19.8.1-sources.jar: zio/aws/wisdom/model/SearchContentResponse.scala <==
package zio.aws.wisdom.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.wisdom.model.primitives.NextToken
import scala.jdk.CollectionConverters.*
final case class SearchContentResponse(
    contentSummaries: Iterable[zio.aws.wisdom.model.ContentSummary],
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.wisdom.model.SearchContentResponse = {
    import SearchContentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.wisdom.model.SearchContentResponse
      .builder()
      .contentSummaries(contentSummaries.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.wisdom.model.SearchContentResponse.ReadOnly =
    zio.aws.wisdom.model.SearchContentResponse.wrap(buildAwsValue())
}
object SearchContentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.wisdom.model.SearchContentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wisdom.model.SearchContentResponse =
      zio.aws.wisdom.model.SearchContentResponse(
        contentSummaries.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def contentSummaries: List[zio.aws.wisdom.model.ContentSummary.ReadOnly]
    def nextToken: Optional[NextToken]
    def getContentSummaries: ZIO[Any, Nothing, List[
      zio.aws.wisdom.model.ContentSummary.ReadOnly
    ]] = ZIO.succeed(contentSummaries)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.wisdom.model.SearchContentResponse
  ) extends zio.aws.wisdom.model.SearchContentResponse.ReadOnly {
    override val contentSummaries
        : List[zio.aws.wisdom.model.ContentSummary.ReadOnly] = impl
      .contentSummaries()
      .asScala
      .map { item =>
        zio.aws.wisdom.model.ContentSummary.wrap(item)
      }
      .toList
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.wisdom.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.wisdom.model.SearchContentResponse
  ): zio.aws.wisdom.model.SearchContentResponse.ReadOnly = new Wrapper(impl)
}
